@@ -302,10 +302,7 @@ class TripleoInventory(object):
                 keystoneauth1.exceptions.catalog.EndpointNotFound):
             return {}
 
-    UNDERCLOUD_SERVICES = [
-        'tripleo_nova_compute', 'tripleo_heat_engine',
-        'tripleo_ironic_conductor', 'tripleo_swift_container_server',
-        'tripleo_swift_object_server', 'tripleo_mistral_engine']
+    UNDERCLOUD_SERVICES = ['tripleo_ironic_conductor']
 
     def get_undercloud_service_list(self):
         """Return list of undercloud services - currently static
@@ -438,11 +435,17 @@ class TripleoInventory(object):
                                                          dynamic)})
 
             if self.plan_name != 'overcloud':
-                ret.setdefault('overcloud',
-                               {'children': self._hosts(['allovercloud'],
-                                                        dynamic),
-                                'deprecated': ('Deprecated by allovercloud '
-                                               'group in Ussuri')})
+                ret.setdefault(
+                    'overcloud',
+                    {
+                        'children': self._hosts(
+                            [
+                                'allovercloud'
+                            ],
+                            dynamic
+                        )
+                    }
+                )
 
         # Associate services with roles
         roles_by_service = self.get_roles_by_service(
@@ -483,6 +486,13 @@ class TripleoInventory(object):
                     svc_host_vars.setdefault('ansible_python_interpreter',
                                              self.ansible_python_interpreter)
 
+        excluded_hosts = self.stack_outputs.get('BlacklistedHostnames', {})
+        excluded_overcloud = ret.setdefault('excluded_overcloud', {})
+        exclude = excluded_overcloud.setdefault('hosts', {})
+        for hostname in excluded_hosts:
+            if hostname:
+                exclude[hostname] = {}
+
     def _get_neutron_data(self):
         if not self.connection:
             LOG.info("Session not set, neutron data will not be used to build "
@@ -621,7 +631,8 @@ class TripleoInventory(object):
                                  sorted(role_networks))
             role_vars.setdefault(
                 'role_networks',
-                [networks_upper[net] for net in role_networks])
+                [networks_upper[net] for net in role_networks
+                 if net != self.host_network])
             role_vars.setdefault('networks_all', networks_all)
             role_vars.setdefault('networks_lower', networks_lower)
 
@@ -832,60 +843,3 @@ def generate_tripleo_ansible_inventory(heat=None,
 
     inv.write_static_inventory(inventory_path)
     return inventory_path
-
-
-def task_core_inventory(stack_outputs, host_network=HOST_NETWORK):
-    inv = {
-        'hosts': {}
-    }
-    task_core_data = stack_outputs.get('RoleConfig',
-                                       {}).get('task_core_data', {})
-    deploy_data = task_core_data.get('deployment_host', {})
-    if deploy_data.get('hostname'):
-        inv['hosts'][deploy_data.get('hostname')] = {'role': 'deployer'}
-
-    # overcloud nodes
-    role_net_hostname_map = stack_outputs.get(
-        'RoleNetHostnameMap', {})
-    for role_name, hostnames in role_net_hostname_map.items():
-        if not hostnames:
-            continue
-        names = hostnames.get(host_network) or []
-        shortnames = [n.split(".%s." % host_network)[0].lower()
-                      for n in names]
-        for name in shortnames:
-            if inv['hosts'].get(name):
-                LOG.warning("task-core inventory already contains %s, "
-                            "overriding it", inv['hosts'].get(name))
-            inv['hosts'][name] = {'role': role_name.lower()}
-    return inv
-
-
-def directord_inventory(stack_outputs, host_network=HOST_NETWORK):
-    inv = {
-        'directord_server': {
-            'args': {},
-            'targets': []
-        },
-        'directord_clients': {
-            'args': {},
-            'targets': []
-        }
-    }
-    task_core_data = stack_outputs.get(
-        'RoleConfig', {}).get('task_core_data', {})
-    deploy_data = task_core_data.get('deployment_host', {})
-    server_targets = inv['directord_server']['targets']
-    if deploy_data.get('hostname'):
-        server_targets.append({'host': deploy_data.get('ip')})
-
-    client_targets = inv['directord_clients']['targets']
-    role_net_ip = stack_outputs.get('RoleNetIpMap', {})
-    for role_name in role_net_ip.keys():
-        # get the host network ips (default is ctlplane)
-        ips = role_net_ip[role_name].get(host_network) or []
-        if not ips:
-            continue
-        for ip in ips:
-            client_targets.append({'host': ip})
-    return inv
