@@ -208,6 +208,16 @@ class TestInventory(base.TestCase):
         self.assertTrue(self.hclient.called_once_with(
             'overcloud', 'KeystoneURL'))
 
+    def test_with_excluded_nodes(self):
+        excluded_output = {
+            'output_key': 'BlacklistedHostnames',
+            'output_value': ['cp-0', '', '']
+            }
+        self.outputs_data['outputs'].append(excluded_output)
+        inventory_group = {'hosts': {'cp-0': {}}}
+        self.assertEquals(inventory_group,
+                          self.inventory.list()['excluded_overcloud'])
+
     def test_no_ips(self):
         for output in self.outputs_data['outputs']:
             if output['output_key'] == 'RoleNetIpMap':
@@ -275,6 +285,9 @@ class TestInventory(base.TestCase):
             'overcloud': {
                 'children': ['allovercloud']
                 },
+            'excluded_overcloud': {
+                'hosts': {}
+                },
             'allovercloud': {
                 'children': ['Compute', 'Controller', 'CustomRole'],
                 'vars': {
@@ -296,13 +309,7 @@ class TestInventory(base.TestCase):
                     'overcloud_admin_password': 'theadminpw',
                     'plan': 'overcloud',
                     'undercloud_service_list': [
-                        'tripleo_nova_compute',
-                        'tripleo_heat_engine',
-                        'tripleo_ironic_conductor',
-                        'tripleo_swift_container_server',
-                        'tripleo_swift_object_server',
-                        'tripleo_mistral_engine'
-                        ],
+                        'tripleo_ironic_conductor']
                     }
                 }
             }
@@ -394,13 +401,7 @@ class TestInventory(base.TestCase):
                     'any_error_fatal': True,
                     'max_fail_percentage': 0,
                     'undercloud_service_list': [
-                        'tripleo_nova_compute',
-                        'tripleo_heat_engine',
-                        'tripleo_ironic_conductor',
-                        'tripleo_swift_container_server',
-                        'tripleo_swift_object_server',
-                        'tripleo_mistral_engine'
-                        ],
+                        'tripleo_ironic_conductor']
                 }
             },
             '_meta': {'hostvars': {}},
@@ -544,12 +545,7 @@ class TestInventory(base.TestCase):
                     'overcloud_admin_password': 'theadminpw',
                     'plan': 'overcloud',
                     'undercloud_service_list': [
-                        'tripleo_nova_compute',
-                        'tripleo_heat_engine',
-                        'tripleo_ironic_conductor',
-                        'tripleo_swift_container_server',
-                        'tripleo_swift_object_server',
-                        'tripleo_mistral_engine'],
+                        'tripleo_ironic_conductor']
                     }
                 }
             }
@@ -586,12 +582,7 @@ class TestInventory(base.TestCase):
                     'overcloud_keystone_url': 'xyz://keystone',
                     'plan': 'overcloud',
                     'undercloud_service_list': [
-                        'tripleo_nova_compute',
-                        'tripleo_heat_engine',
-                        'tripleo_ironic_conductor',
-                        'tripleo_swift_container_server',
-                        'tripleo_swift_object_server',
-                        'tripleo_mistral_engine'],
+                        'tripleo_ironic_conductor']
                 }
             },
             'Controller': {
@@ -672,6 +663,9 @@ class TestInventory(base.TestCase):
             'overcloud': {
                 'children': {'allovercloud': {}}
             },
+            'excluded_overcloud': {
+                'hosts': {}
+            },
             'allovercloud': {
                 'children': {
                     'Compute': {},
@@ -811,7 +805,7 @@ class TestInventory(base.TestCase):
                           'networks_all': ['InternalApi'],
                           'networks_lower': {'InternalApi': 'internal_api',
                                              'ctlplane': 'ctlplane'},
-                          'role_networks': ['ctlplane', 'InternalApi'],
+                          'role_networks': ['InternalApi'],
                           'serial': 1,
                           'tripleo_role_name': 'Controller',
                           'tripleo_role_networks': ['ctlplane', 'internal_api']
@@ -844,7 +838,7 @@ class TestInventory(base.TestCase):
                           'networks_all': ['InternalApi'],
                           'networks_lower': {'InternalApi': 'internal_api',
                                              'ctlplane': 'ctlplane'},
-                          'role_networks': ['ctlplane', 'InternalApi'],
+                          'role_networks': ['InternalApi'],
                           'serial': 1,
                           'tripleo_role_name': 'Compute',
                           'tripleo_role_networks': ['ctlplane', 'internal_api']
@@ -887,7 +881,7 @@ class TestInventory(base.TestCase):
                          'networks_all': ['InternalApi'],
                          'networks_lower': {'InternalApi': 'internal_api',
                                             'ctlplane': 'ctlplane'},
-                         'role_networks': ['ctlplane', 'InternalApi'],
+                         'role_networks': ['InternalApi'],
                          'serial': 1,
                          'tripleo_role_name': 'Controller',
                          'tripleo_role_networks': ['ctlplane', 'internal_api']
@@ -913,7 +907,7 @@ class TestInventory(base.TestCase):
                          'networks_all': ['InternalApi'],
                          'networks_lower': {'InternalApi': 'internal_api',
                                             'ctlplane': 'ctlplane'},
-                         'role_networks': ['ctlplane', 'InternalApi'],
+                         'role_networks': ['InternalApi'],
                          'serial': 1,
                          'tripleo_role_name': 'Compute',
                          'tripleo_role_networks': ['ctlplane', 'internal_api']
@@ -993,12 +987,8 @@ class TestInventory(base.TestCase):
                          'overcloud_keystone_url': 'xyz://keystone',
                          'plan': 'overcloud',
                          'undercloud_service_list': [
-                             'tripleo_nova_compute',
-                             'tripleo_heat_engine',
-                             'tripleo_ironic_conductor',
-                             'tripleo_swift_container_server',
-                             'tripleo_swift_object_server',
-                             'tripleo_mistral_engine']}},
+                             'tripleo_ironic_conductor']}
+            },
             'Controller': {
                 'hosts': {
                     'c-0': {
@@ -1045,7 +1035,7 @@ class TestInventory(base.TestCase):
                     'networks_all': ['InternalApi'],
                     'networks_lower': {'InternalApi': 'internal_api',
                                        'ctlplane': 'ctlplane'},
-                    'role_networks': ['ctlplane', 'InternalApi'],
+                    'role_networks': ['InternalApi'],
                     'serial': 1,
                     'tripleo_role_name': 'Controller',
                     'tripleo_role_networks': ['ctlplane', 'internal_api']}
@@ -1081,7 +1071,7 @@ class TestInventory(base.TestCase):
                          'networks_all': ['InternalApi'],
                          'networks_lower': {'InternalApi': 'internal_api',
                                             'ctlplane': 'ctlplane'},
-                         'role_networks': ['ctlplane', 'InternalApi'],
+                         'role_networks': ['InternalApi'],
                          'serial': 1,
                          'tripleo_role_name': 'Compute',
                          'tripleo_role_networks': ['ctlplane', 'internal_api']}
@@ -1109,7 +1099,7 @@ class TestInventory(base.TestCase):
                          'networks_all': ['InternalApi'],
                          'networks_lower': {'InternalApi': 'internal_api',
                                             'ctlplane': 'ctlplane'},
-                         'role_networks': ['ctlplane'],
+                         'role_networks': [],
                          'serial': 1,
                          'tripleo_role_name': 'CustomRole',
                          'tripleo_role_networks': ['ctlplane']}
