@@ -55,8 +55,6 @@ class TestPasswords(base.TestCase):
     def test_fernet_keys_and_credentials(self, mock_create_creds):
 
         keys = [uuidutils.generate_uuid(dashed=False),
-                uuidutils.generate_uuid(dashed=False),
-                uuidutils.generate_uuid(dashed=False),
                 uuidutils.generate_uuid(dashed=False),
                 uuidutils.generate_uuid(dashed=False),
                 uuidutils.generate_uuid(dashed=False),
@@ -78,13 +76,8 @@ class TestPasswords(base.TestCase):
                 value = password_utils.generate_passwords()
         self.assertIn(value['KeystoneCredential0'], keys)
         self.assertIn(value['KeystoneCredential1'], keys)
-        self.assertIn(value['KeystoneFernetKey0'], keys)
-        self.assertIn(value['KeystoneFernetKey1'], keys)
         self.assertIn(value['BarbicanSimpleCryptoKek'], keys)
 
-        self.assertNotEqual(value['KeystoneFernetKey0'],
-                            value['KeystoneFernetKey1'])
-
         self.assertNotEqual(value['KeystoneCredential0'],
                             value['KeystoneCredential1'])
         self.assertEqual(len(value['OctaviaServerCertsKeyPassphrase']), 32)
